#!/bin/bash
set -e -u

#what we want:
#/etc/rc.local
# TC_load.sh --atboot 6 7 fun
# TC_load.sh --atboot 1 5 work
# 
# #crontab
# * * * * 6-7 TC_load.sh --load fun
# * * * * 1-5 TC_load.sh --load work

#check if inside time window

add_extension()
{
	EXT=$2
	DIR=$(dirname "$1")
	filename=$DIR/$(basename "$1" .$EXT).$EXT
	echo $filename
}

# Check if all parameters are present
# If no, exit
if [ $# -ne 2 ]
then
        echo "usage :"
        echo "`basename $0` user file"
        exit 0
fi

TC_PATH=yourpath
TC_STATUS=$TC_PATH/tc_status
EXT=tcs
TC_BANNED=$TC_PATH/tc_banned
TC_ALLOWED=$TC_PATH/tc_allowed
TC_DESCRIPTION=$TC_PATH/tc_description
USERNAME=$1
NEW_SETTING=$2

#check that status file exists and is not empty
if [ ! -s $TC_STATUS ]
then
    echo "ERROR: $TC_STATUS does not exist or is empty."
    exit 1
fi

#make sure setting files end with the correct extension
CURRENT_SETTING=`cat $TC_STATUS`
CURRENT_ARCHIVE=$(add_extension $CURRENT_SETTING $EXT)
NEW_ARCHIVE=$(add_extension $NEW_SETTING $EXT)

#check if those settings aren't already loaded
if [ $CURRENT_ARCHIVE = $NEW_ARCHIVE ]
then
    echo "$NEW_ARCHIVE already loaded."
    exit 0
fi

#if not, load them
echo "$NEW_ARCHIVE not loaded."

#save current settings (in case restrictions have been added ;) )
$TC_PATH/create_tcs_file.sh $CURRENT_ARCHIVE

#load TC settings
echo "Loading settings from $NEW_ARCHIVE..."
tar -Pxzvf $NEW_ARCHIVE >/dev/null
echo "Loaded settings from $NEW_ARCHIVE."

#add user to allowed groups
cat $TC_ALLOWED | xargs -n1 $TC_PATH/add_user_to_group.sh $USERNAME

#remove user from banned groups
cat $TC_BANNED | xargs -n1 $TC_PATH/remove_user_from_group.sh $USERNAME

#restart DG
echo "Restarting dansguardian"
/etc/init.d/dansguardian restart

#change status
echo "Setting current status to $NEW_ARCHIVE."
echo $NEW_ARCHIVE >$TC_STATUS

#logout if -l option given
echo "Logging you out so that group changes take effect. Sorry."
$TC_PATH/logout.sh $USERNAME
